@@ -322,26 +322,6 @@ eel_gtk_menu_insert_separator (GtkMenu *menu, int index)
 	return GTK_MENU_ITEM (menu_item);
 }
 
-GtkWidget *
-eel_gtk_menu_tool_button_get_button (GtkMenuToolButton *tool_button)
-{
-	GtkContainer *container;
-	GList *children;
-	GtkWidget *button;
-
-	g_return_val_if_fail (GTK_IS_MENU_TOOL_BUTTON (tool_button), NULL);
-
-	/* The menu tool button's button is the first child
-	 * of the child hbox. */
-	container = GTK_CONTAINER (gtk_bin_get_child (GTK_BIN (tool_button)));
-	children = gtk_container_get_children (container);
-	button = GTK_WIDGET (children->data);
-
-	g_list_free (children);
-
-	return button;
-}
-
 /**
  * eel_gtk_label_make_bold.
  *
