@@ -34,15 +34,17 @@ G_BEGIN_DECLS
 
 typedef enum {
   NAUTILUS_DEBUG_APPLICATION = 1 << 1,
-  NAUTILUS_DEBUG_DBUS = 1 << 2,
-  NAUTILUS_DEBUG_DIRECTORY_VIEW = 1 << 3,
-  NAUTILUS_DEBUG_FILE = 1 << 4,
-  NAUTILUS_DEBUG_ICON_CONTAINER = 1 << 5,
-  NAUTILUS_DEBUG_LIST_VIEW = 1 << 6,
-  NAUTILUS_DEBUG_MIME = 1 << 7,
-  NAUTILUS_DEBUG_PLACES = 1 << 8,
-  NAUTILUS_DEBUG_SMCLIENT = 1 << 9,
-  NAUTILUS_DEBUG_WINDOW = 1 << 10,
+  NAUTILUS_DEBUG_BOOKMARKS = 1 << 2,
+  NAUTILUS_DEBUG_DBUS = 1 << 3,
+  NAUTILUS_DEBUG_DIRECTORY_VIEW = 1 << 4,
+  NAUTILUS_DEBUG_FILE = 1 << 5,
+  NAUTILUS_DEBUG_ICON_CONTAINER = 1 << 6,
+  NAUTILUS_DEBUG_ICON_VIEW = 1 << 7,
+  NAUTILUS_DEBUG_LIST_VIEW = 1 << 8,
+  NAUTILUS_DEBUG_MIME = 1 << 9,
+  NAUTILUS_DEBUG_PLACES = 1 << 10,
+  NAUTILUS_DEBUG_SMCLIENT = 1 << 11,
+  NAUTILUS_DEBUG_WINDOW = 1 << 12,
 } DebugFlags;
 
 void nautilus_debug_set_flags (DebugFlags flags);
