@@ -32,7 +32,6 @@
 #include "nautilus-global-preferences.h"
 #include "nautilus-file-utilities.h"
 #include <math.h>
-#include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-graphic-effects.h>
 #include <eel/eel-string.h>
 #include <eel/eel-debug.h>
@@ -116,8 +115,6 @@ static NautilusThumbnailInfo *currently_thumbnailing = NULL;
 
 static GnomeDesktopThumbnailFactory *thumbnail_factory = NULL;
 
-static int thumbnail_icon_size = 0;
-
 static gboolean
 get_file_mtime (const char *file_uri, time_t* mtime)
 {
@@ -357,10 +354,14 @@ thumbnail_loader_size_prepared (GdkPixbufLoader *loader,
 				ThumbnailLoadArgs *args)
 {
 	int size = MAX (width, height);
+	int thumbnail_icon_size;
 
 	args->original_width = width;
 	args->original_height = height;
 
+	thumbnail_icon_size = g_settings_get_int (nautilus_icon_view_preferences,
+						  NAUTILUS_PREFERENCES_ICON_VIEW_THUMBNAIL_SIZE);
+
 	if (args->force_nominal) {
 		args->base_size = size;                        
 	} else if (args->base_size == 0) {
@@ -424,12 +425,6 @@ get_pixbuf_from_data (const unsigned char *buffer,
 	ThumbnailLoadArgs args;
 	GError *error;
 
-	if (thumbnail_icon_size == 0) {
-		eel_g_settings_add_auto_int (nautilus_icon_view_preferences,
-					     NAUTILUS_PREFERENCES_ICON_VIEW_THUMBNAIL_SIZE,
-					     &thumbnail_icon_size);
-	}
-
 	loader = gdk_pixbuf_loader_new ();
 	g_signal_connect (loader, "size-prepared",
 			  G_CALLBACK (thumbnail_loader_size_prepared),
