@@ -345,6 +345,7 @@ action_about_nautilus_callback (GtkAction *action,
 		"Robin * Slomkowski",
 		"Seth Nickell",
 		"Susan Kare",
+		"Tomas Bzatek",
 		NULL
 	};
 	const gchar *documenters[] = {
@@ -376,7 +377,7 @@ action_about_nautilus_callback (GtkAction *action,
 			       "comments", _("Nautilus lets you organize "
 					     "files and folders, both on "
 					     "your computer and online."),
-			       "copyright", _("Copyright \xC2\xA9 1999-2010 "
+			       "copyright", _("Copyright \xC2\xA9 1999-2011 "
 					      "The Nautilus authors"),
 			       "license", license_trans,
 			       "wrap-license", TRUE,
@@ -422,7 +423,7 @@ action_nautilus_manual_callback (GtkAction *action,
 		nautilus_launch_application_from_command (gtk_window_get_screen (GTK_WINDOW (window)), "gnome-help", FALSE, NULL);
 	} else {
 		gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (window)),
-			      "ghelp:user-guide#gosnautilus-1",
+			      "ghelp:gnome-help#files",
 			      gtk_get_current_event_time (), &error);
 	}
 
